summaryrefslogtreecommitdiffstats
path: root/include/httpd.h
diff options
context:
space:
mode:
authorDavid Reid <dreid@apache.org>2000-11-08 12:35:38 +0100
committerDavid Reid <dreid@apache.org>2000-11-08 12:35:38 +0100
commit33aabfee3fd2c840b50fd1a0dddeead1cdf8bb14 (patch)
tree55539bed9e940d581717d903ad4f2f845c072b75 /include/httpd.h
parentfix the byterange filter. (diff)
downloadapache2-33aabfee3fd2c840b50fd1a0dddeead1cdf8bb14.tar.xz
apache2-33aabfee3fd2c840b50fd1a0dddeead1cdf8bb14.zip
Start of moving to apr_port_t in the server code. This will probably the first
of a few... git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@86866 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/httpd.h')
-rw-r--r--include/httpd.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/httpd.h b/include/httpd.h
index 76a0ea3ca9..6aa52234e6 100644
--- a/include/httpd.h
+++ b/include/httpd.h
@@ -904,7 +904,7 @@ struct server_addr_rec {
/** The bound address, for this server */
apr_in_addr host_addr;
/** The bound port, for this server */
- unsigned short host_port;
+ apr_port_t host_port;
/** The name given in <VirtualHost> */
char *virthost;
};
@@ -928,7 +928,7 @@ struct server_rec {
/** The server hostname */
char *server_hostname;
/** for redirects, etc. */
- unsigned short port;
+ apr_port_t port;
/* Log files --- note that transfer log is now in the modules... */
@@ -1277,10 +1277,10 @@ AP_DECLARE(char *) ap_escape_html(apr_pool_t *p, const char *s);
* @param port The port the server is running on
* @param r The current request
* @return The server's hostname
* @deffunc char *ap_construct_server(apr_pool_t *p, const char *hostname, unsiged port, const request_rec *r)
*/
AP_DECLARE(char *) ap_construct_server(apr_pool_t *p, const char *hostname,
- unsigned port, const request_rec *r);
+ apr_port_t port, const request_rec *r);
/**
* Escape a shell command
* @param p The pool to allocate out of
@@ -1569,9 +1569,9 @@ char *ap_get_local_host(apr_pool_t *p);
* @param hostname The hostname to parse
* @param port The port found in the hostname
* @return The address of the server
- * @deffunc unsigned long ap_get_virthost_addr(char *hostname, unsigned shor *port)
+ * @deffunc unsigned long ap_get_virthost_addr(char *hostname, apr_port_t *port)
*/
-unsigned long ap_get_virthost_addr(char *hostname, unsigned short *port);
+unsigned long ap_get_virthost_addr(char *hostname, apr_port_t *port);
/*
* Redefine assert() to something more useful for an Apache...
@@ -1277,10 +1277,10 @@ AP_DECLARE(char *) ap_escape_html(apr_pool_t *p, const char *s);
* @param r The current request
* @return The server's hostname
- * @deffunc char *ap_construct_server(apr_pool_t *p, const char *hostname, unsiged port, const request_rec *r)
+ * @deffunc char *ap_construct_server(apr_pool_t *p, const char *hostname, apr_port_t port, const request_rec *r)
*/
AP_DECLARE(char *) ap_construct_server(apr_pool_t *p, const char *hostname,